@@ -61,7 +61,7 @@ class MidiFileSynth:
         self.create_midifile(track)
         if self.__child_pid:
             os.kill(self.__child_pid, signal.SIGQUIT)
-            os.wait(self.__child_pid)
+            os.wait()
             self.__child_pid = None
         pid = os.fork()
         if pid == 0:
