@@ -63,8 +63,10 @@ class LessonfileCommon:
         parser.parse_file(filename)
         self._idx = 0
         self.m_transpose = mpd.MusicalPitch("c'")
-        self.__header = parser.m_blocks[0][1]
-        self.header = _Header(self.__header)
+        H = map(lambda e: e[1], 
+                               filter(lambda e: e[0] == 'header',
+                                      parser.m_blocks))
+        self.header = _Header(H[0])
         self.m_questions = map(lambda e: e[1], 
                                filter(lambda e: e[0] == 'question',
                                       parser.m_blocks[1:]))
@@ -279,7 +281,7 @@ class LessonfileManagerParser(dataparser.Dataparser):
             self._idx = len(self._data)
             return
         if self.m_context == self.m_globals:
-            raise "No block to glose. Lineno:", self._lineno
+            raise "No block to close. Lineno:", self._lineno
         self.m_context = self.m_globals
 
 
