@@ -57,6 +57,7 @@ class Teacher(abstract.Teacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window, no_notebook=1)
+        self.set_usize(400, -1)
         self.config_box.hide()
         self.m_key_bindings = {'new_ak': self.new_question,
                                'play_first_note_ak': self.m_t.play_question,
@@ -64,6 +65,7 @@ class Gui(abstract.Gui):
                                'play_all_ak': self.m_t.play_all_notes}
         self.g_music_displayer = mpd.MusicDisplayer()
         self.g_music_displayer.clear()
+        self.g_music_displayer.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
         self.practise_box.pack_start(self.g_music_displayer)
         
         gu.bButton(self.action_area, _("New"), self.new_question)
